/****************************************************************************
** Meta object code from reading C++ file 'pipeline.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.4.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/phonon-backend-gstreamer-4.8.2/gstreamer/pipeline.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pipeline.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.4.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_Phonon__Gstreamer__Pipeline_t {
    QByteArrayData data[39];
    char stringdata[556];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Phonon__Gstreamer__Pipeline_t, stringdata) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Phonon__Gstreamer__Pipeline_t qt_meta_stringdata_Phonon__Gstreamer__Pipeline = {
    {
QT_MOC_LITERAL(0, 0, 27), // "Phonon::Gstreamer::Pipeline"
QT_MOC_LITERAL(1, 28, 14), // "windowIDNeeded"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 3), // "eos"
QT_MOC_LITERAL(4, 48, 7), // "warning"
QT_MOC_LITERAL(5, 56, 7), // "message"
QT_MOC_LITERAL(6, 64, 15), // "durationChanged"
QT_MOC_LITERAL(7, 80, 13), // "totalDuration"
QT_MOC_LITERAL(8, 94, 17), // "trackCountChanged"
QT_MOC_LITERAL(9, 112, 6), // "tracks"
QT_MOC_LITERAL(10, 119, 9), // "buffering"
QT_MOC_LITERAL(11, 129, 12), // "stateChanged"
QT_MOC_LITERAL(12, 142, 8), // "GstState"
QT_MOC_LITERAL(13, 151, 8), // "oldState"
QT_MOC_LITERAL(14, 160, 8), // "newState"
QT_MOC_LITERAL(15, 169, 24), // "videoAvailabilityChanged"
QT_MOC_LITERAL(16, 194, 14), // "textTagChanged"
QT_MOC_LITERAL(17, 209, 6), // "stream"
QT_MOC_LITERAL(18, 216, 15), // "audioTagChanged"
QT_MOC_LITERAL(19, 232, 12), // "errorMessage"
QT_MOC_LITERAL(20, 245, 17), // "Phonon::ErrorType"
QT_MOC_LITERAL(21, 263, 4), // "type"
QT_MOC_LITERAL(22, 268, 15), // "metaDataChanged"
QT_MOC_LITERAL(23, 284, 26), // "QMultiMap<QString,QString>"
QT_MOC_LITERAL(24, 311, 15), // "mouseOverActive"
QT_MOC_LITERAL(25, 327, 8), // "isActive"
QT_MOC_LITERAL(26, 336, 21), // "availableMenusChanged"
QT_MOC_LITERAL(27, 358, 38), // "QList<MediaController::Naviga..."
QT_MOC_LITERAL(28, 397, 15), // "seekableChanged"
QT_MOC_LITERAL(29, 413, 10), // "isSeekable"
QT_MOC_LITERAL(30, 424, 13), // "aboutToFinish"
QT_MOC_LITERAL(31, 438, 13), // "streamChanged"
QT_MOC_LITERAL(32, 452, 20), // "pluginInstallFailure"
QT_MOC_LITERAL(33, 473, 3), // "msg"
QT_MOC_LITERAL(34, 477, 21), // "pluginInstallComplete"
QT_MOC_LITERAL(35, 499, 20), // "pluginInstallStarted"
QT_MOC_LITERAL(36, 520, 8), // "setState"
QT_MOC_LITERAL(37, 529, 20), // "GstStateChangeReturn"
QT_MOC_LITERAL(38, 550, 5) // "state"

    },
    "Phonon::Gstreamer::Pipeline\0windowIDNeeded\0"
    "\0eos\0warning\0message\0durationChanged\0"
    "totalDuration\0trackCountChanged\0tracks\0"
    "buffering\0stateChanged\0GstState\0"
    "oldState\0newState\0videoAvailabilityChanged\0"
    "textTagChanged\0stream\0audioTagChanged\0"
    "errorMessage\0Phonon::ErrorType\0type\0"
    "metaDataChanged\0QMultiMap<QString,QString>\0"
    "mouseOverActive\0isActive\0availableMenusChanged\0"
    "QList<MediaController::NavigationMenu>\0"
    "seekableChanged\0isSeekable\0aboutToFinish\0"
    "streamChanged\0pluginInstallFailure\0"
    "msg\0pluginInstallComplete\0"
    "pluginInstallStarted\0setState\0"
    "GstStateChangeReturn\0state"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Phonon__Gstreamer__Pipeline[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      21,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      17,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  119,    2, 0x06 /* Public */,
       3,    0,  120,    2, 0x06 /* Public */,
       4,    1,  121,    2, 0x06 /* Public */,
       6,    1,  124,    2, 0x06 /* Public */,
       8,    1,  127,    2, 0x06 /* Public */,
      10,    1,  130,    2, 0x06 /* Public */,
      11,    2,  133,    2, 0x06 /* Public */,
      15,    1,  138,    2, 0x06 /* Public */,
      16,    1,  141,    2, 0x06 /* Public */,
      18,    1,  144,    2, 0x06 /* Public */,
      19,    2,  147,    2, 0x06 /* Public */,
      22,    1,  152,    2, 0x06 /* Public */,
      24,    1,  155,    2, 0x06 /* Public */,
      26,    1,  158,    2, 0x06 /* Public */,
      28,    1,  161,    2, 0x06 /* Public */,
      30,    0,  164,    2, 0x06 /* Public */,
      31,    0,  165,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      32,    1,  166,    2, 0x08 /* Private */,
      34,    0,  169,    2, 0x08 /* Private */,
      35,    0,  170,    2, 0x08 /* Private */,

 // methods: name, argc, parameters, tag, flags
      36,    1,  171,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::LongLong,    7,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, 0x80000000 | 12, 0x80000000 | 12,   13,   14,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 20,    5,   21,
    QMetaType::Void, 0x80000000 | 23,    2,
    QMetaType::Void, QMetaType::Bool,   25,
    QMetaType::Void, 0x80000000 | 27,    2,
    QMetaType::Void, QMetaType::Bool,   29,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,   33,
    QMetaType::Void,
    QMetaType::Void,

 // methods: parameters
    0x80000000 | 37, 0x80000000 | 12,   38,

       0        // eod
};

void Phonon::Gstreamer::Pipeline::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Pipeline *_t = static_cast<Pipeline *>(_o);
        switch (_id) {
        case 0: _t->windowIDNeeded(); break;
        case 1: _t->eos(); break;
        case 2: _t->warning((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->durationChanged((*reinterpret_cast< qint64(*)>(_a[1]))); break;
        case 4: _t->trackCountChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->buffering((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->stateChanged((*reinterpret_cast< GstState(*)>(_a[1])),(*reinterpret_cast< GstState(*)>(_a[2]))); break;
        case 7: _t->videoAvailabilityChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->textTagChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->audioTagChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->errorMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< Phonon::ErrorType(*)>(_a[2]))); break;
        case 11: _t->metaDataChanged((*reinterpret_cast< QMultiMap<QString,QString>(*)>(_a[1]))); break;
        case 12: _t->mouseOverActive((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->availableMenusChanged((*reinterpret_cast< QList<MediaController::NavigationMenu>(*)>(_a[1]))); break;
        case 14: _t->seekableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->aboutToFinish(); break;
        case 16: _t->streamChanged(); break;
        case 17: _t->pluginInstallFailure((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 18: _t->pluginInstallComplete(); break;
        case 19: _t->pluginInstallStarted(); break;
        case 20: { GstStateChangeReturn _r = _t->setState((*reinterpret_cast< GstState(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< GstStateChangeReturn*>(_a[0]) = _r; }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Phonon::ErrorType >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (Pipeline::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Pipeline::windowIDNeeded)) {
                *result = 0;
            }
        }
        {
            typedef void (Pipeline::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Pipeline::eos)) {
                *result = 1;
            }
        }
        {
            typedef void (Pipeline::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Pipeline::warning)) {
                *result = 2;
            }
        }
        {
            typedef void (Pipeline::*_t)(qint64 );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Pipeline::durationChanged)) {
                *result = 3;
            }
        }
        {
            typedef void (Pipeline::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Pipeline::trackCountChanged)) {
                *result = 4;
            }
        }
        {
            typedef void (Pipeline::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Pipeline::buffering)) {
                *result = 5;
            }
        }
        {
            typedef void (Pipeline::*_t)(GstState , GstState );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Pipeline::stateChanged)) {
                *result = 6;
            }
        }
        {
            typedef void (Pipeline::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Pipeline::videoAvailabilityChanged)) {
                *result = 7;
            }
        }
        {
            typedef void (Pipeline::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Pipeline::textTagChanged)) {
                *result = 8;
            }
        }
        {
            typedef void (Pipeline::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Pipeline::audioTagChanged)) {
                *result = 9;
            }
        }
        {
            typedef void (Pipeline::*_t)(const QString & , Phonon::ErrorType );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Pipeline::errorMessage)) {
                *result = 10;
            }
        }
        {
            typedef void (Pipeline::*_t)(QMultiMap<QString,QString> );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Pipeline::metaDataChanged)) {
                *result = 11;
            }
        }
        {
            typedef void (Pipeline::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Pipeline::mouseOverActive)) {
                *result = 12;
            }
        }
        {
            typedef void (Pipeline::*_t)(QList<MediaController::NavigationMenu> );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Pipeline::availableMenusChanged)) {
                *result = 13;
            }
        }
        {
            typedef void (Pipeline::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Pipeline::seekableChanged)) {
                *result = 14;
            }
        }
        {
            typedef void (Pipeline::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Pipeline::aboutToFinish)) {
                *result = 15;
            }
        }
        {
            typedef void (Pipeline::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Pipeline::streamChanged)) {
                *result = 16;
            }
        }
    }
}

const QMetaObject Phonon::Gstreamer::Pipeline::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Phonon__Gstreamer__Pipeline.data,
      qt_meta_data_Phonon__Gstreamer__Pipeline,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *Phonon::Gstreamer::Pipeline::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Phonon::Gstreamer::Pipeline::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_Phonon__Gstreamer__Pipeline.stringdata))
        return static_cast<void*>(const_cast< Pipeline*>(this));
    return QObject::qt_metacast(_clname);
}

int Phonon::Gstreamer::Pipeline::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void Phonon::Gstreamer::Pipeline::windowIDNeeded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, Q_NULLPTR);
}

// SIGNAL 1
void Phonon::Gstreamer::Pipeline::eos()
{
    QMetaObject::activate(this, &staticMetaObject, 1, Q_NULLPTR);
}

// SIGNAL 2
void Phonon::Gstreamer::Pipeline::warning(const QString & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Phonon::Gstreamer::Pipeline::durationChanged(qint64 _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Phonon::Gstreamer::Pipeline::trackCountChanged(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Phonon::Gstreamer::Pipeline::buffering(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Phonon::Gstreamer::Pipeline::stateChanged(GstState _t1, GstState _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Phonon::Gstreamer::Pipeline::videoAvailabilityChanged(bool _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void Phonon::Gstreamer::Pipeline::textTagChanged(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void Phonon::Gstreamer::Pipeline::audioTagChanged(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void Phonon::Gstreamer::Pipeline::errorMessage(const QString & _t1, Phonon::ErrorType _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void Phonon::Gstreamer::Pipeline::metaDataChanged(QMultiMap<QString,QString> _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void Phonon::Gstreamer::Pipeline::mouseOverActive(bool _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void Phonon::Gstreamer::Pipeline::availableMenusChanged(QList<MediaController::NavigationMenu> _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void Phonon::Gstreamer::Pipeline::seekableChanged(bool _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void Phonon::Gstreamer::Pipeline::aboutToFinish()
{
    QMetaObject::activate(this, &staticMetaObject, 15, Q_NULLPTR);
}

// SIGNAL 16
void Phonon::Gstreamer::Pipeline::streamChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
