/****************************************************************************
** Meta object code from reading C++ file 'audiooutput.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.4.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/phonon-backend-gstreamer-4.8.2/gstreamer/audiooutput.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'audiooutput.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.4.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_Phonon__Gstreamer__AudioOutput_t {
    QByteArrayData data[5];
    char stringdata[74];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Phonon__Gstreamer__AudioOutput_t, stringdata) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Phonon__Gstreamer__AudioOutput_t qt_meta_stringdata_Phonon__Gstreamer__AudioOutput = {
    {
QT_MOC_LITERAL(0, 0, 30), // "Phonon::Gstreamer::AudioOutput"
QT_MOC_LITERAL(1, 31, 13), // "volumeChanged"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 9), // "newVolume"
QT_MOC_LITERAL(4, 56, 17) // "audioDeviceFailed"

    },
    "Phonon::Gstreamer::AudioOutput\0"
    "volumeChanged\0\0newVolume\0audioDeviceFailed"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Phonon__Gstreamer__AudioOutput[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   24,    2, 0x06 /* Public */,
       4,    0,   27,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QReal,    3,
    QMetaType::Void,

       0        // eod
};

void Phonon::Gstreamer::AudioOutput::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        AudioOutput *_t = static_cast<AudioOutput *>(_o);
        switch (_id) {
        case 0: _t->volumeChanged((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 1: _t->audioDeviceFailed(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (AudioOutput::*_t)(qreal );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AudioOutput::volumeChanged)) {
                *result = 0;
            }
        }
        {
            typedef void (AudioOutput::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AudioOutput::audioDeviceFailed)) {
                *result = 1;
            }
        }
    }
}

const QMetaObject Phonon::Gstreamer::AudioOutput::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Phonon__Gstreamer__AudioOutput.data,
      qt_meta_data_Phonon__Gstreamer__AudioOutput,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *Phonon::Gstreamer::AudioOutput::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Phonon::Gstreamer::AudioOutput::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_Phonon__Gstreamer__AudioOutput.stringdata))
        return static_cast<void*>(const_cast< AudioOutput*>(this));
    if (!strcmp(_clname, "AudioOutputInterface"))
        return static_cast< AudioOutputInterface*>(const_cast< AudioOutput*>(this));
    if (!strcmp(_clname, "MediaNode"))
        return static_cast< MediaNode*>(const_cast< AudioOutput*>(this));
    if (!strcmp(_clname, "4AudioOutputInterface.phonon.kde.org"))
        return static_cast< Phonon::AudioOutputInterface*>(const_cast< AudioOutput*>(this));
    if (!strcmp(_clname, "org.phonon.gstreamer.MediaNode"))
        return static_cast< Phonon::Gstreamer::MediaNode*>(const_cast< AudioOutput*>(this));
    return QObject::qt_metacast(_clname);
}

int Phonon::Gstreamer::AudioOutput::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void Phonon::Gstreamer::AudioOutput::volumeChanged(qreal _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Phonon::Gstreamer::AudioOutput::audioDeviceFailed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
