/****************************************************************************
** Meta object code from reading C++ file 'videowidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.4.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/phonon-backend-gstreamer-4.8.2/gstreamer/videowidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'videowidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.4.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_Phonon__Gstreamer__VideoWidget_t {
    QByteArrayData data[8];
    char stringdata[94];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Phonon__Gstreamer__VideoWidget_t, stringdata) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Phonon__Gstreamer__VideoWidget_t qt_meta_stringdata_Phonon__Gstreamer__VideoWidget = {
    {
QT_MOC_LITERAL(0, 0, 30), // "Phonon::Gstreamer::VideoWidget"
QT_MOC_LITERAL(1, 31, 12), // "setMovieSize"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 4), // "size"
QT_MOC_LITERAL(4, 50, 15), // "mouseOverActive"
QT_MOC_LITERAL(5, 66, 6), // "active"
QT_MOC_LITERAL(6, 73, 5), // "syncX"
QT_MOC_LITERAL(7, 79, 14) // "updateWindowID"

    },
    "Phonon::Gstreamer::VideoWidget\0"
    "setMovieSize\0\0size\0mouseOverActive\0"
    "active\0syncX\0updateWindowID"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Phonon__Gstreamer__VideoWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x0a /* Public */,
       4,    1,   37,    2, 0x0a /* Public */,
       6,    0,   40,    2, 0x0a /* Public */,
       7,    0,   41,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QSize,    3,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Phonon::Gstreamer::VideoWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        VideoWidget *_t = static_cast<VideoWidget *>(_o);
        switch (_id) {
        case 0: _t->setMovieSize((*reinterpret_cast< const QSize(*)>(_a[1]))); break;
        case 1: _t->mouseOverActive((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->syncX(); break;
        case 3: _t->updateWindowID(); break;
        default: ;
        }
    }
}

const QMetaObject Phonon::Gstreamer::VideoWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_Phonon__Gstreamer__VideoWidget.data,
      qt_meta_data_Phonon__Gstreamer__VideoWidget,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *Phonon::Gstreamer::VideoWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Phonon::Gstreamer::VideoWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_Phonon__Gstreamer__VideoWidget.stringdata))
        return static_cast<void*>(const_cast< VideoWidget*>(this));
    if (!strcmp(_clname, "Phonon::VideoWidgetInterface44"))
        return static_cast< Phonon::VideoWidgetInterface44*>(const_cast< VideoWidget*>(this));
    if (!strcmp(_clname, "MediaNode"))
        return static_cast< MediaNode*>(const_cast< VideoWidget*>(this));
    if (!strcmp(_clname, "VideoWidgetInterface44.phonon.kde.org"))
        return static_cast< Phonon::VideoWidgetInterface44*>(const_cast< VideoWidget*>(this));
    if (!strcmp(_clname, "org.phonon.gstreamer.MediaNode"))
        return static_cast< Phonon::Gstreamer::MediaNode*>(const_cast< VideoWidget*>(this));
    return QWidget::qt_metacast(_clname);
}

int Phonon::Gstreamer::VideoWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
