/****************************************************************************
** Meta object code from reading C++ file 'mediaobject.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.4.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/phonon-backend-gstreamer-4.8.2/gstreamer/mediaobject.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mediaobject.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.4.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_Phonon__Gstreamer__MediaObject_t {
    QByteArrayData data[54];
    char stringdata[832];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Phonon__Gstreamer__MediaObject_t, stringdata) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Phonon__Gstreamer__MediaObject_t qt_meta_stringdata_Phonon__Gstreamer__MediaObject = {
    {
QT_MOC_LITERAL(0, 0, 30), // "Phonon::Gstreamer::MediaObject"
QT_MOC_LITERAL(1, 31, 20), // "currentSourceChanged"
QT_MOC_LITERAL(2, 52, 0), // ""
QT_MOC_LITERAL(3, 53, 11), // "MediaSource"
QT_MOC_LITERAL(4, 65, 9), // "newSource"
QT_MOC_LITERAL(5, 75, 12), // "stateChanged"
QT_MOC_LITERAL(6, 88, 13), // "Phonon::State"
QT_MOC_LITERAL(7, 102, 8), // "newstate"
QT_MOC_LITERAL(8, 111, 8), // "oldstate"
QT_MOC_LITERAL(9, 120, 4), // "tick"
QT_MOC_LITERAL(10, 125, 4), // "time"
QT_MOC_LITERAL(11, 130, 15), // "metaDataChanged"
QT_MOC_LITERAL(12, 146, 26), // "QMultiMap<QString,QString>"
QT_MOC_LITERAL(13, 173, 15), // "seekableChanged"
QT_MOC_LITERAL(14, 189, 15), // "hasVideoChanged"
QT_MOC_LITERAL(15, 205, 8), // "finished"
QT_MOC_LITERAL(16, 214, 20), // "prefinishMarkReached"
QT_MOC_LITERAL(17, 235, 13), // "aboutToFinish"
QT_MOC_LITERAL(18, 249, 16), // "totalTimeChanged"
QT_MOC_LITERAL(19, 266, 6), // "length"
QT_MOC_LITERAL(20, 273, 12), // "bufferStatus"
QT_MOC_LITERAL(21, 286, 13), // "percentFilled"
QT_MOC_LITERAL(22, 300, 12), // "titleChanged"
QT_MOC_LITERAL(23, 313, 22), // "availableTitlesChanged"
QT_MOC_LITERAL(24, 336, 21), // "availableMenusChanged"
QT_MOC_LITERAL(25, 358, 38), // "QList<MediaController::Naviga..."
QT_MOC_LITERAL(26, 397, 14), // "chapterChanged"
QT_MOC_LITERAL(27, 412, 24), // "availableChaptersChanged"
QT_MOC_LITERAL(28, 437, 12), // "angleChanged"
QT_MOC_LITERAL(29, 450, 22), // "availableAnglesChanged"
QT_MOC_LITERAL(30, 473, 25), // "availableSubtitlesChanged"
QT_MOC_LITERAL(31, 499, 29), // "availableAudioChannelsChanged"
QT_MOC_LITERAL(32, 529, 12), // "requestState"
QT_MOC_LITERAL(33, 542, 22), // "handleTrackCountChange"
QT_MOC_LITERAL(34, 565, 6), // "tracks"
QT_MOC_LITERAL(35, 572, 15), // "getSubtitleInfo"
QT_MOC_LITERAL(36, 588, 6), // "stream"
QT_MOC_LITERAL(37, 595, 19), // "getAudioChannelInfo"
QT_MOC_LITERAL(38, 615, 8), // "emitTick"
QT_MOC_LITERAL(39, 624, 9), // "beginPlay"
QT_MOC_LITERAL(40, 634, 18), // "autoDetectSubtitle"
QT_MOC_LITERAL(41, 653, 10), // "logWarning"
QT_MOC_LITERAL(42, 664, 17), // "handleEndOfStream"
QT_MOC_LITERAL(43, 682, 17), // "handleStateChange"
QT_MOC_LITERAL(44, 700, 8), // "GstState"
QT_MOC_LITERAL(45, 709, 8), // "oldState"
QT_MOC_LITERAL(46, 718, 8), // "newState"
QT_MOC_LITERAL(47, 727, 20), // "handleDurationChange"
QT_MOC_LITERAL(48, 748, 19), // "handleAboutToFinish"
QT_MOC_LITERAL(49, 768, 18), // "handleStreamChange"
QT_MOC_LITERAL(50, 787, 8), // "setError"
QT_MOC_LITERAL(51, 796, 11), // "errorString"
QT_MOC_LITERAL(52, 808, 17), // "Phonon::ErrorType"
QT_MOC_LITERAL(53, 826, 5) // "error"

    },
    "Phonon::Gstreamer::MediaObject\0"
    "currentSourceChanged\0\0MediaSource\0"
    "newSource\0stateChanged\0Phonon::State\0"
    "newstate\0oldstate\0tick\0time\0metaDataChanged\0"
    "QMultiMap<QString,QString>\0seekableChanged\0"
    "hasVideoChanged\0finished\0prefinishMarkReached\0"
    "aboutToFinish\0totalTimeChanged\0length\0"
    "bufferStatus\0percentFilled\0titleChanged\0"
    "availableTitlesChanged\0availableMenusChanged\0"
    "QList<MediaController::NavigationMenu>\0"
    "chapterChanged\0availableChaptersChanged\0"
    "angleChanged\0availableAnglesChanged\0"
    "availableSubtitlesChanged\0"
    "availableAudioChannelsChanged\0"
    "requestState\0handleTrackCountChange\0"
    "tracks\0getSubtitleInfo\0stream\0"
    "getAudioChannelInfo\0emitTick\0beginPlay\0"
    "autoDetectSubtitle\0logWarning\0"
    "handleEndOfStream\0handleStateChange\0"
    "GstState\0oldState\0newState\0"
    "handleDurationChange\0handleAboutToFinish\0"
    "handleStreamChange\0setError\0errorString\0"
    "Phonon::ErrorType\0error"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Phonon__Gstreamer__MediaObject[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      35,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      20,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  189,    2, 0x06 /* Public */,
       5,    2,  192,    2, 0x06 /* Public */,
       9,    1,  197,    2, 0x06 /* Public */,
      11,    1,  200,    2, 0x06 /* Public */,
      13,    1,  203,    2, 0x06 /* Public */,
      14,    1,  206,    2, 0x06 /* Public */,
      15,    0,  209,    2, 0x06 /* Public */,
      16,    1,  210,    2, 0x06 /* Public */,
      17,    0,  213,    2, 0x06 /* Public */,
      18,    1,  214,    2, 0x06 /* Public */,
      20,    1,  217,    2, 0x06 /* Public */,
      22,    1,  220,    2, 0x06 /* Public */,
      23,    1,  223,    2, 0x06 /* Public */,
      24,    1,  226,    2, 0x06 /* Public */,
      26,    1,  229,    2, 0x06 /* Public */,
      27,    1,  232,    2, 0x06 /* Public */,
      28,    1,  235,    2, 0x06 /* Public */,
      29,    1,  238,    2, 0x06 /* Public */,
      30,    0,  241,    2, 0x06 /* Public */,
      31,    0,  242,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      32,    1,  243,    2, 0x0a /* Public */,
      33,    1,  246,    2, 0x08 /* Private */,
      35,    1,  249,    2, 0x08 /* Private */,
      37,    1,  252,    2, 0x08 /* Private */,
      38,    0,  255,    2, 0x08 /* Private */,
      39,    0,  256,    2, 0x08 /* Private */,
      40,    0,  257,    2, 0x08 /* Private */,
      41,    1,  258,    2, 0x08 /* Private */,
      42,    0,  261,    2, 0x08 /* Private */,
      43,    2,  262,    2, 0x08 /* Private */,
      47,    1,  267,    2, 0x08 /* Private */,
      48,    0,  270,    2, 0x08 /* Private */,
      49,    0,  271,    2, 0x08 /* Private */,

 // methods: name, argc, parameters, tag, flags
      50,    2,  272,    2, 0x01 /* Protected */,
      50,    1,  277,    2, 0x21 /* Protected | MethodCloned */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6, 0x80000000 | 6,    7,    8,
    QMetaType::Void, QMetaType::LongLong,   10,
    QMetaType::Void, 0x80000000 | 12,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::LongLong,   19,
    QMetaType::Void, QMetaType::Int,   21,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, 0x80000000 | 25,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, QMetaType::Int,   34,
    QMetaType::Void, QMetaType::Int,   36,
    QMetaType::Void, QMetaType::Int,   36,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 44, 0x80000000 | 44,   45,   46,
    QMetaType::Void, QMetaType::LongLong,    2,
    QMetaType::Void,
    QMetaType::Void,

 // methods: parameters
    QMetaType::Void, QMetaType::QString, 0x80000000 | 52,   51,   53,
    QMetaType::Void, QMetaType::QString,   51,

       0        // eod
};

void Phonon::Gstreamer::MediaObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MediaObject *_t = static_cast<MediaObject *>(_o);
        switch (_id) {
        case 0: _t->currentSourceChanged((*reinterpret_cast< const MediaSource(*)>(_a[1]))); break;
        case 1: _t->stateChanged((*reinterpret_cast< Phonon::State(*)>(_a[1])),(*reinterpret_cast< Phonon::State(*)>(_a[2]))); break;
        case 2: _t->tick((*reinterpret_cast< qint64(*)>(_a[1]))); break;
        case 3: _t->metaDataChanged((*reinterpret_cast< QMultiMap<QString,QString>(*)>(_a[1]))); break;
        case 4: _t->seekableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->hasVideoChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->finished(); break;
        case 7: _t->prefinishMarkReached((*reinterpret_cast< qint32(*)>(_a[1]))); break;
        case 8: _t->aboutToFinish(); break;
        case 9: _t->totalTimeChanged((*reinterpret_cast< qint64(*)>(_a[1]))); break;
        case 10: _t->bufferStatus((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->titleChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->availableTitlesChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->availableMenusChanged((*reinterpret_cast< QList<MediaController::NavigationMenu>(*)>(_a[1]))); break;
        case 14: _t->chapterChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->availableChaptersChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->angleChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->availableAnglesChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->availableSubtitlesChanged(); break;
        case 19: _t->availableAudioChannelsChanged(); break;
        case 20: _t->requestState((*reinterpret_cast< Phonon::State(*)>(_a[1]))); break;
        case 21: _t->handleTrackCountChange((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 22: _t->getSubtitleInfo((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 23: _t->getAudioChannelInfo((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 24: _t->emitTick(); break;
        case 25: _t->beginPlay(); break;
        case 26: _t->autoDetectSubtitle(); break;
        case 27: _t->logWarning((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 28: _t->handleEndOfStream(); break;
        case 29: _t->handleStateChange((*reinterpret_cast< GstState(*)>(_a[1])),(*reinterpret_cast< GstState(*)>(_a[2]))); break;
        case 30: _t->handleDurationChange((*reinterpret_cast< qint64(*)>(_a[1]))); break;
        case 31: _t->handleAboutToFinish(); break;
        case 32: _t->handleStreamChange(); break;
        case 33: _t->setError((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< Phonon::ErrorType(*)>(_a[2]))); break;
        case 34: _t->setError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Phonon::State >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Phonon::State >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Phonon::ErrorType >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (MediaObject::*_t)(const MediaSource & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MediaObject::currentSourceChanged)) {
                *result = 0;
            }
        }
        {
            typedef void (MediaObject::*_t)(Phonon::State , Phonon::State );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MediaObject::stateChanged)) {
                *result = 1;
            }
        }
        {
            typedef void (MediaObject::*_t)(qint64 );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MediaObject::tick)) {
                *result = 2;
            }
        }
        {
            typedef void (MediaObject::*_t)(QMultiMap<QString,QString> );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MediaObject::metaDataChanged)) {
                *result = 3;
            }
        }
        {
            typedef void (MediaObject::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MediaObject::seekableChanged)) {
                *result = 4;
            }
        }
        {
            typedef void (MediaObject::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MediaObject::hasVideoChanged)) {
                *result = 5;
            }
        }
        {
            typedef void (MediaObject::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MediaObject::finished)) {
                *result = 6;
            }
        }
        {
            typedef void (MediaObject::*_t)(qint32 );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MediaObject::prefinishMarkReached)) {
                *result = 7;
            }
        }
        {
            typedef void (MediaObject::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MediaObject::aboutToFinish)) {
                *result = 8;
            }
        }
        {
            typedef void (MediaObject::*_t)(qint64 );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MediaObject::totalTimeChanged)) {
                *result = 9;
            }
        }
        {
            typedef void (MediaObject::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MediaObject::bufferStatus)) {
                *result = 10;
            }
        }
        {
            typedef void (MediaObject::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MediaObject::titleChanged)) {
                *result = 11;
            }
        }
        {
            typedef void (MediaObject::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MediaObject::availableTitlesChanged)) {
                *result = 12;
            }
        }
        {
            typedef void (MediaObject::*_t)(QList<MediaController::NavigationMenu> );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MediaObject::availableMenusChanged)) {
                *result = 13;
            }
        }
        {
            typedef void (MediaObject::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MediaObject::chapterChanged)) {
                *result = 14;
            }
        }
        {
            typedef void (MediaObject::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MediaObject::availableChaptersChanged)) {
                *result = 15;
            }
        }
        {
            typedef void (MediaObject::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MediaObject::angleChanged)) {
                *result = 16;
            }
        }
        {
            typedef void (MediaObject::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MediaObject::availableAnglesChanged)) {
                *result = 17;
            }
        }
        {
            typedef void (MediaObject::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MediaObject::availableSubtitlesChanged)) {
                *result = 18;
            }
        }
        {
            typedef void (MediaObject::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MediaObject::availableAudioChannelsChanged)) {
                *result = 19;
            }
        }
    }
}

const QMetaObject Phonon::Gstreamer::MediaObject::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Phonon__Gstreamer__MediaObject.data,
      qt_meta_data_Phonon__Gstreamer__MediaObject,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *Phonon::Gstreamer::MediaObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Phonon::Gstreamer::MediaObject::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_Phonon__Gstreamer__MediaObject.stringdata))
        return static_cast<void*>(const_cast< MediaObject*>(this));
    if (!strcmp(_clname, "MediaObjectInterface"))
        return static_cast< MediaObjectInterface*>(const_cast< MediaObject*>(this));
    if (!strcmp(_clname, "AddonInterface"))
        return static_cast< AddonInterface*>(const_cast< MediaObject*>(this));
    if (!strcmp(_clname, "MediaNode"))
        return static_cast< MediaNode*>(const_cast< MediaObject*>(this));
    if (!strcmp(_clname, "MediaObjectInterface3.phonon.kde.org"))
        return static_cast< Phonon::MediaObjectInterface*>(const_cast< MediaObject*>(this));
    if (!strcmp(_clname, "AddonInterface0.2.phonon.kde.org"))
        return static_cast< Phonon::AddonInterface*>(const_cast< MediaObject*>(this));
    if (!strcmp(_clname, "org.phonon.gstreamer.MediaNode"))
        return static_cast< Phonon::Gstreamer::MediaNode*>(const_cast< MediaObject*>(this));
    return QObject::qt_metacast(_clname);
}

int Phonon::Gstreamer::MediaObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    return _id;
}

// SIGNAL 0
void Phonon::Gstreamer::MediaObject::currentSourceChanged(const MediaSource & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Phonon::Gstreamer::MediaObject::stateChanged(Phonon::State _t1, Phonon::State _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Phonon::Gstreamer::MediaObject::tick(qint64 _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Phonon::Gstreamer::MediaObject::metaDataChanged(QMultiMap<QString,QString> _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Phonon::Gstreamer::MediaObject::seekableChanged(bool _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Phonon::Gstreamer::MediaObject::hasVideoChanged(bool _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Phonon::Gstreamer::MediaObject::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 6, Q_NULLPTR);
}

// SIGNAL 7
void Phonon::Gstreamer::MediaObject::prefinishMarkReached(qint32 _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void Phonon::Gstreamer::MediaObject::aboutToFinish()
{
    QMetaObject::activate(this, &staticMetaObject, 8, Q_NULLPTR);
}

// SIGNAL 9
void Phonon::Gstreamer::MediaObject::totalTimeChanged(qint64 _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void Phonon::Gstreamer::MediaObject::bufferStatus(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void Phonon::Gstreamer::MediaObject::titleChanged(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void Phonon::Gstreamer::MediaObject::availableTitlesChanged(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void Phonon::Gstreamer::MediaObject::availableMenusChanged(QList<MediaController::NavigationMenu> _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void Phonon::Gstreamer::MediaObject::chapterChanged(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void Phonon::Gstreamer::MediaObject::availableChaptersChanged(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void Phonon::Gstreamer::MediaObject::angleChanged(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void Phonon::Gstreamer::MediaObject::availableAnglesChanged(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}

// SIGNAL 18
void Phonon::Gstreamer::MediaObject::availableSubtitlesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, Q_NULLPTR);
}

// SIGNAL 19
void Phonon::Gstreamer::MediaObject::availableAudioChannelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
